@@ -215,7 +215,7 @@ terminal_util_show_about (GtkWindow *transient_parent)
 
   licence_text = terminal_util_get_licence_text ();
 
-  vte_version = g_strdup_printf (_("Using VTE version %d.%d.%d"),
+  vte_version = g_strdup_printf (_("Using VTE version %u.%u.%u"),
                                  vte_get_major_version (),
                                  vte_get_minor_version (),
                                  vte_get_micro_version ());
@@ -430,10 +430,20 @@ terminal_util_load_builder_resource (const char *path,
 
   if (main_object_name) {
     GObject *main_object;
+    GtkWidget *action_area;
 
     main_object = gtk_builder_get_object (builder, main_object_name);
     g_object_set_data_full (main_object, "builder", g_object_ref (builder), (GDestroyNotify) g_object_unref);
     g_signal_connect (main_object, "destroy", G_CALLBACK (main_object_destroy_cb), NULL);
+
+    /* Fixup dialogue padding, #735242 */
+    if (GTK_IS_DIALOG (main_object) &&
+        (action_area = (GtkWidget *) gtk_builder_get_object (builder, "dialog-action-area"))) {
+      gtk_widget_set_margin_left   (action_area, 5);
+      gtk_widget_set_margin_right  (action_area, 5);
+      gtk_widget_set_margin_top    (action_area, 5);
+      gtk_widget_set_margin_bottom (action_area, 5);
+    }
   }
 }
 
